==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_label.js <==
/*****************************************************
 * TextArea form object
 *
 * @2Do: swiss inherite __update from generic!
 *****************************************************/

_me = obj_label.prototype;
function obj_label(){};

/**
 * @brief: CONSTRUCTOR, create label HTML element to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
	/* creates ELM directly, because simlicity of object */
	this.__eIN = mkElement('label',{"name":this._pathName+'main',"id":this._pathName+'main',"className":this._type});
	this._main.appendChild(this.__eIN);

	var me = this;
	this.__eIN.onclick = function(e){
		e = e || window.event;
		if (me._onclick) me._onclick(e);
		me.__exeEvent('onclick',e,{"owner":me});
	}
};

/**
 * @brief: get label content
 *         set label content
 * @param: v - html content of label element
 * @date : 20.4.2006 18:02:11
 **/
_me._value = function(v){
	if (typeof v != 'undefined') {
		this.__eIN.innerHTML = v;
		return v;
	}
	return this.__eIN.innerHTML;
};

/**
 * @brief: Updata method, keeps content synchronized
 * @param: sDataSet - name of data set which is calling this method
 **/
_me.__update = function (sDataSet){
	if (!this._listener)
		this._listener = sDataSet;
	else
	if(sDataSet && this._listener != sDataSet) return;

	this._value(dataSet.get(this._listener,this._listenerPath));
};

/**
* @brief: binds label to checkbox or radio button
* @param: sElmName - name of binded form element
**/
_me._bind = function(sElmName){
	this.__eIN.setAttribute("for",sElmName);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_label.js <==
/*****************************************************
 * TextArea form object
 *
 * @2Do: swiss inherite __update from generic!
 *****************************************************/

_me = obj_label.prototype;
function obj_label(){};

/**
 * @brief: CONSTRUCTOR, create label HTML element to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
	/* creates ELM directly, because simlicity of object */
	this.__eIN = mkElement('label',{"name":this._pathName+'main',"id":this._pathName+'main'});
	this._main.appendChild(this.__eIN);
	this.__eIN.className = this._type;

	var me = this;
	this.__eIN.onclick = function(e){
		e = e || window.event;
		if (me._onclick) me._onclick(e);
		me.__exeEvent('onclick',e,{"owner":me});
	}
};

/**
 * @brief: get label content
 *         set label content
 * @param: v - html content of label element
 * @date : 20.4.2006 18:02:11
 **/
_me._value = function(v){
	if (typeof v != 'undefined') {
		this.__eIN.innerHTML = v;
		return v;
	}
	return this.__eIN.innerHTML;
};

/**
 * @brief: Updata method, keeps content synchronized
 * @param: sDataSet - name of data set which is calling this method
 **/
_me.__update = function (sDataSet){
	if (!this._listener)
		this._listener = sDataSet;
	else
	if(sDataSet && this._listener != sDataSet) return;

	this._value(dataSet.get(this._listener,this._listenerPath));
};

/**
* @brief: binds label to checkbox or radio button
* @param: sElmName - name of binded form element
**/
_me._bind = function(sElmName){
	this.__eIN.setAttribute("for",sElmName);
};
